@@ -200,7 +200,7 @@ def test_constrained_layout9():
 
 
 @image_comparison(['constrained_layout10.png'], style='mpl20',
-                  tol=0.02 if platform.machine() == 'x86_64' else 0.032)
+                  tol=0 if False else 0.032)
 def test_constrained_layout10():
     """Test for handling legend outside axis"""
     fig, axs = plt.subplots(2, 2, layout="constrained")
@@ -721,3 +721,23 @@ def test_layout_leak():
     gc.collect()
     assert not any(isinstance(obj, mpl._layoutgrid.LayoutGrid)
                    for obj in gc.get_objects())
+
+
+def test_submerged_subfig():
+    """
+    Test that the submerged margin logic does not get called multiple times
+    on same axes if it is already in a subfigure
+    """
+    fig = plt.figure(figsize=(4, 5), layout='constrained')
+    figures = fig.subfigures(3, 1)
+    axs = []
+    for f in figures.flatten():
+        gs = f.add_gridspec(2, 2)
+        for i in range(2):
+            axs += [f.add_subplot(gs[i, 0])]
+            axs[-1].plot()
+        f.add_subplot(gs[:, 1]).plot()
+    fig.draw_without_rendering()
+    for ax in axs[1:]:
+        assert np.allclose(ax.get_position().bounds[-1],
+                           axs[0].get_position().bounds[-1], atol=1e-6)
